@@ -10,33 +10,31 @@ You can search for remote data URLS based on the event name:
 
 >>> from gwosc.locate import get_event_urls
 >>> get_event_urls('GW150914')
-['https://www.gw-openscience.org/eventapi/json/GWTC-1-confident/GW150914/v3/H-H1_GWOSC_4KHZ_R1-1126259447-32.hdf5',
- 'https://www.gw-openscience.org/eventapi/json/GWTC-1-confident/GW150914/v3/H-H1_GWOSC_4KHZ_R1-1126257415-4096.hdf5',
- 'https://www.gw-openscience.org/eventapi/json/GWTC-1-confident/GW150914/v3/L-L1_GWOSC_4KHZ_R1-1126259447-32.hdf5',
- 'https://www.gw-openscience.org/eventapi/json/GWTC-1-confident/GW150914/v3/L-L1_GWOSC_4KHZ_R1-1126257415-4096.hdf5']
+['https://gwosc.org/eventapi/json/GWTC-1-confident/GW150914/v3/H-H1_GWOSC_4KHZ_R1-1126259447-32.hdf5',
+ 'https://gwosc.org/eventapi/json/GWTC-1-confident/GW150914/v3/H-H1_GWOSC_4KHZ_R1-1126257415-4096.hdf5',
+ 'https://gwosc.org/eventapi/json/GWTC-1-confident/GW150914/v3/L-L1_GWOSC_4KHZ_R1-1126259447-32.hdf5',
+ 'https://gwosc.org/eventapi/json/GWTC-1-confident/GW150914/v3/L-L1_GWOSC_4KHZ_R1-1126257415-4096.hdf5']
 
 You can down-select the URLs using keyword arguments:
 
 >>> get_event_urls('GW150914', detector='L1', duration=32)
-['https://www.gw-openscience.org/eventapi/json/GWTC-1-confident/GW150914/v3/L-L1_GWOSC_4KHZ_R1-1126259447-32.hdf5']
+['https://gwosc.org/eventapi/json/GWTC-1-confident/GW150914/v3/L-L1_GWOSC_4KHZ_R1-1126259447-32.hdf5']
 
 You can search for remote data URLs based on the GPS time interval as
 follows:
 
 >>> from gwosc.locate import get_urls
 >>> get_urls('L1', 968650000, 968660000)
-['https://www.gw-openscience.org/archive/data/S6/967835648/L-L1_LOSC_4_V1-968646656-4096.hdf5',
- 'https://www.gw-openscience.org/archive/data/S6/967835648/L-L1_LOSC_4_V1-968650752-4096.hdf5',
- 'https://www.gw-openscience.org/archive/data/S6/967835648/L-L1_LOSC_4_V1-968654848-4096.hdf5',
- 'https://www.gw-openscience.org/archive/data/S6/967835648/L-L1_LOSC_4_V1-968658944-4096.hdf5']
+['https://gwosc.org/archive/data/S6/967835648/L-L1_LOSC_4_V1-968646656-4096.hdf5',
+ 'https://gwosc.org/archive/data/S6/967835648/L-L1_LOSC_4_V1-968650752-4096.hdf5',
+ 'https://gwosc.org/archive/data/S6/967835648/L-L1_LOSC_4_V1-968654848-4096.hdf5',
+ 'https://gwosc.org/archive/data/S6/967835648/L-L1_LOSC_4_V1-968658944-4096.hdf5']
 
 By default, this method will return the paths to HDF5 files for the 4 kHz
 sample-rate data, these can be specified as keyword arguments.
 For full information, see :func:`get_urls`.
 """  # noqa: E501
 
-import warnings
-
 from . import (
     api,
     datasets,
@@ -51,7 +49,6 @@ __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
 def get_urls(
         detector, start, end,
         dataset=None,
-        tag=None,
         version=None,
         sample_rate=4096,
         format='hdf5',
@@ -94,15 +91,6 @@ def get_urls(
     start = int(start)
     end = int(end)
 
-    if tag is not None:
-        warnings.warn(
-            "the `tag` keyword to get_urls is deprecated, GWOSC no longer "
-            "releases multiple datasets for events, please use the `dataset` "
-            "and `version` keyword arguments to manually select the host "
-            "dataset for URLs",
-            DeprecationWarning,
-        )
-
     for dstype in ("event", "run"):
         dsets = datasets._iter_datasets(
             match=dataset,
@@ -134,6 +122,7 @@ def get_urls(
                     format=format,
                     sample_rate=sample_rate,
                     version=version,
+                    host=host,
                 )
 
             # if full span covered, return now
